@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for iotanalytics service client
 
@@ -10,11 +11,13 @@ Usage::
     client: IoTAnalyticsClient = boto3.client("iotanalytics")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from datetime import datetime
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_iotanalytics.paginator import (
     ListChannelsPaginator,
     ListDatasetContentsPaginator,
@@ -382,3 +385,6 @@ class IoTAnalyticsClient:
         """
         [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
