@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for iotanalytics service client paginators.
 
@@ -24,10 +25,11 @@ Usage::
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_iotanalytics.type_defs import (
     ListChannelsResponseTypeDef,
     ListDatasetContentsResponseTypeDef,
@@ -37,7 +39,6 @@ from mypy_boto3_iotanalytics.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListChannelsPaginator",
     "ListDatasetContentsPaginator",
